<?php
/**
 * Class for handle ajax request
 */
if ( ! class_exists( 'IPVicre_Ajax' )) {

    class IPVicre_Ajax
    {
        /**
         * Take ajax action name
         *
         * @var string
         */
        protected $_action;
        
        /**
         * Take ajax action handlers
         *
         * @var array
         */
        protected $_handlers = array(
            'ipvicre_update'            => 'update',
            'ipvicre_delete'            => 'delete',
            'ipvicre_video_update'      => 'video_update',
            'ipvicre_video_delete'      => 'video_delete',
            'ipvicre_video_sort'        => 'video_sort',
            'ipvicre_video_get_edit'    => 'video_get_edit',
            'ipvicre_get_slug'          => 'get_slug',
            'ipvicre_setting'           => 'setting',
            'ipvicre_savestat'          => 'save_stat',
            'ipvicre_getchart'          => 'get_chart',
            'ipvicre_getmore'           => 'get_more'
        );
        
        /**
         * Class constructor
         *
         * @return void
         */
        public function __construct()
        {
        }
        
        /**
         * Get action name
         *
         * @return string
         */
        public function getAction()
        {
            return $this->_action;
        }
        
        /**
         * Set action
         *
         * @param  string $action
         * @return IPShortcode_Ajax
         */
        public function setAction( $action )
        {
            $this->_action = sanitize_title( $action );
        }
        
        /**
         * Execute request
         *
         * @param  string $action
         * @return IPShortcode_Ajax
         */
        public function exec()
        {
            $data = array_merge( $_GET, $_POST );
            if ( empty( $data['doajax'] ) || empty( $data['ipvicre'] ) || empty( $data['action'] ) ) {
                return true;
            }
            $this->setAction( $data['action'] );
            
            $action   = $this->getAction();
            $handlers = (array)$this->_handlers;
            if ( array_key_exists( $action, $handlers )) {
                $handler = $handlers[$action];
                if ( method_exists( $this, $handler )) {
                    $this->$handler();
                }
            }
            return true;
        }
        
        /**
         * Update
         *
         * @return void
         */
        public function update()
        {
            $redirect = false;
            $is_add   = false;
            $error    = true;
            if ( ! empty( $_POST['isadd'] )) {
                $is_add = true;
            }
            if ( ! empty( $_POST['page_id'] )) {
                $pageId = absint( $_POST['page_id'] );
                if ( $page = get_post( $pageId ) ) {
                    $this->_update_page( $page );
                } else {
                    $pageId = 0;
                }
            } else {
                $pageId = $this->_add_page();
            }
            if ( $pageId )
            {
                $error = false;
                $model = new IPVicre_Model();
                $model->save_setting( $pageId );
            }
            if ( $error ) {
                $status  = 0;
                $pageId  = 0;
                if ( $is_add ) {
                    $message = __( 'Failed to create a video page.', 'wp_video_page_generator' );
                } else {
                    $message = __( 'Failed to save video page.', 'wp_video_page_generator' );
                }
            } else {
                $status = 1;
                if ( $is_add ) {
                    $message  = __( 'Successfully create a video page.', 'wp_video_page_generator' );
                    $redirect = admin_url() . 'admin.php?page=ipvicre&action=edit&id=' . $pageId . '&create=1&tab=ipvicre-section-video';
                } else {
                    $message = __( 'Successfully to save video page.', 'wp_video_page_generator' );
                }
            }
            $result = array(
                'status'   => $status,
                'message'  => $message,
                'pageid'   => $pageId
            );
            if ( $redirect ) {
                $result['redirect'] = $redirect;
            }
            echo json_encode( $result );
            die();
        }
        
        /**
         * Add new video page
         *
         * @return int
         */
        protected function _add_page()
        {
            global $user_ID;
            
            if ( empty( $_POST['name'] )) {
                $title = 'Unknown';
            } else {
                $title = apply_filters( 'single_post_title', $_POST['name'] );
            }
            if ( $_POST['status'] == 'true' ) {
                $status = 'publish';
            } else {
                $status = 'draft';
            }
            $dataPost = array(
                'post_status'  => $status, 
                'post_type'    => 'ipvicre-item', 
                'post_author'  => $user_ID,
                'post_title'   => $title,
                'post_content' => ''
            );
            if ( ! empty( $_POST['slug'] )) {
                $dataPost['post_name'] = apply_filters( 'pre_term_name', $_POST['slug'] );
            }
            $result = wp_insert_post( $dataPost );
            return $result;
        }
        
        /**
         * Update video page
         *
         * @param  object $page
         * @return boolean
         */
        protected function _update_page( $page )
        {
            $result   = 0;
            $dataPost = array();
            if ( ! empty( $_POST['name'] ) && $_POST['name'] != $page->post_title ) {
                $dataPost['post_title'] = apply_filters( 'single_post_title', $_POST['name'] );
            }
            if ( $_POST['status'] == 'true' ) {
                $status = 'publish';
            } else {
                $status = 'draft';
            }
            if ( $status != $page->post_status ) {
                $dataPost['post_status'] = $status;
            }
            if ( ! empty( $dataPost )) {
                $dataPost['ID'] = $page->ID;
                $result = wp_update_post( $dataPost );
            }
            return $result;
        }
        
        /**
         * Processing ajax for delete object
         *
         * @return void
         */
        public function delete()
        {
            $item = false;
            if ( ! empty( $_REQUEST['id'] )) {
                $id   = absint( $_REQUEST['id'] );
                $item = get_post( $id );
            }
            if ( ! $item ) {
                echo json_encode( array(
                    'status'   => 0,
                    'message'  => __( 'Error system', 'wp_video_page_generator' )
                ) );
                die();
            }
            $result = wp_delete_post( $item->ID, true );
            if ( $result ) {
                echo json_encode( array(
                    'status'   => 1,
                    'message'  => __( 'Successfully remove the video page', 'wp_video_page_generator' ),
                    'redirect' => admin_url() . 'admin.php?page=ipvicre&delete=1'
                ) );
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to remove the video page', 'wp_video_page_generator' )
                ) );
            }
            die();
        }
        
        /**
         * Update video
         *
         * @return void
         */
        public function video_update()
        {
            $pageId = 0;
            if ( ! empty( $_POST['page'] )) {
                $pageId = absint( $_POST['page'] );
            }
            if ( ! $page = @get_post( $pageId )) {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed', 'wp_video_page_generator' )
                ) );
                die();
            
            }
            $redirect = false;
            $is_add   = false;
            $error    = true;
            $ohtml    = false;
            if ( ! empty( $_POST['isadd'] )) {
                $is_add = true;
            }
            if ( ! empty( $_POST['video_id'] )) {
                $videoId = absint( $_POST['video_id'] );
                if ( $video = get_post( $videoId ) ) {
                    $this->_update_video( $video );
                } else {
                    $videoId = 0;
                }
            } else {
                $videoId = $this->_add_video( $page );
            }
            if ( $videoId )
            {
                $error = false;
                $model = new IPVicre_Model();
                $model->save_video_setting( $videoId );
            }
            if ( $error ) {
                $status   = 0;
                $videoId  = 0;
                if ( $is_add ) {
                    $message = __( 'Failed to create a video item.', 'wp_video_page_generator' );
                } else {
                    $message = __( 'Failed to save video item.', 'wp_video_page_generator' );
                }
            } else {
                $status = 1;
                if ( $is_add ) 
                {
                    $message = __( 'Successfully create a video item.', 'wp_video_page_generator' );
                    $video   = get_post( $videoId );
                    $list    = new IPVicre_List_Video( $pageId );
                    $ohtml   = $list->create_item( $video );
                } 
                else {
                    $message = __( 'Successfully to save video item.', 'wp_video_page_generator' );
                }
            }
            $result = array(
                'status'   => $status,
                'message'  => $message,
                'videoid'  => $videoId
            );
            if ( $ohtml ) {
                $result['video'] = $ohtml;
            }
            if ( ! empty( $videoId )) {
                $video = get_post( $videoId );
                $result['title']  = $video->post_title;
                if ( $video->post_status == 'publish' ) {
                    $label = '<span class="ipbe-label ipbe-label-success">' . __( 'Publish' ) . '</span>';
                } else {
                    $label = '<span class="ipbe-label ipbe-label-danger">' . __( 'Draft' ) . '</span>';
                }
                $result['label'] = $label;
            }
            echo json_encode( $result );
            die();
        }
        
        /**
         * Add new video item
         *
         * @param  object $page
         * @return int
         */
        protected function _add_video( $page )
        {
            global $user_ID;
            
            if ( empty( $_POST['video_headline'] )) {
                $title = 'Unknown';
            } else {
                $title = apply_filters( 'single_post_title', $_POST['video_headline'] );
            }
            if ( $_POST['video_status'] == 'true' ) {
                $status = 'publish';
            } else {
                $status = 'draft';
            }
            $dataPost = array(
                'post_status'  => $status, 
                'post_type'    => 'ipvicre-video-item', 
                'post_author'  => $user_ID,
                'post_title'   => $title,
                'post_content' => '',
                'post_parent'  => $page->ID
            );
            $result = wp_insert_post( $dataPost );
            return $result;
        }
        
        /**
         * Update video item
         *
         * @param  object $video
         * @return boolean
         */
        protected function _update_video( $video )
        {
            $result    = 0;
            $data_post = array();
            if ( ! empty( $_POST['video_headline'] ) && $_POST['video_headline'] != $video->post_title ) {
                $data_post['post_title'] = apply_filters( 'single_post_title', $_POST['video_headline'] );
            }
            if ( $_POST['video_status'] == 'true' ) {
                $status = 'publish';
            } else {
                $status = 'draft';
            }
            if ( $status != $video->post_status ) {
                $data_post['post_status'] = $status;
            }
            if ( ! empty( $data_post )) {
                $data_post['ID'] = $video->ID;
                $result = wp_update_post( $data_post );
            }
            return $result;
        }
        
        /**
         * Processing ajax for delete video item
         *
         * @return void
         */
        public function video_delete()
        {
            $item = false;
            if ( ! empty( $_REQUEST['id'] )) {
                $id   = absint( $_REQUEST['id'] );
                $item = get_post( $id );
            }
            if ( ! $item ) {
                echo json_encode( array(
                    'status'   => 0,
                    'message'  => __( 'Error system', 'wp_video_page_generator' )
                ) );
                die();
            }
            $result = wp_delete_post( $item->ID, true );
            if ( $result ) {
                echo json_encode( array(
                    'status'   => 1,
                    'message'  => __( 'Successfully remove the video item', 'wp_video_page_generator' )
                ) );
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to remove the video item', 'wp_video_page_generator' )
                ) );
            }
            die();
        }
        
        /**
         * Get form edit video
         *
         * @return void
         */
        public function video_get_edit()
        {
            if ( ! empty( $_GET['id'] )) {
                $videoId = absint( $_GET['id'] );
                if ( $video = get_post( $videoId ))
                {
                    $admin   = new IPVicre_Admin();
                    $admin->video_form( $video );
                    die();
                }
            }
            echo '';
            die();
        }
        
        /**
         * Sorting video item
         *
         * @return void
         */
        public function video_sort()
        {
            if ( ! empty( $_POST['video'] ) && ! empty( $_POST['list'] )) 
            {
                $videoId = absint( $_POST['video'] );
                if ( $video = get_post( $videoId )) 
                {
                    $_list = trim( $_POST['list'], ',' );
                    $lists = explode( ',', $_list );
                    $index = 1;
                    foreach( $lists as $id )
                    {
                        $id = absint( $id );
                        if ( $video = get_post( $id )) {
                            $data_post = array(
                                'ID'            => $video->ID,
                                'menu_order'    => $index
                            );
                            $result = wp_update_post( $data_post );
                        }
                        $index++;
                    }
                }
            }
            echo json_encode( array(
                'status'  => 1
            ));
            die();
        }
        
        /**
         * Get slug
         *
         * @return void
         */
        public function get_slug()
        {
            $data   = array_merge( $_POST, $_GET );
            $postId = 0;
            if ( ! empty( $data['pageid'] )) {
                $postId = absint( $data['pageid'] );
            }
            if ( ! empty( $data['name'] )) {
                $slug = sanitize_title( $data['name'] );
                $slug = wp_unique_post_slug( $slug, $postId, 1, 'ipvicre-item', 0 );
                echo json_encode( array(
                    'status' => 1,
                    'slug'   => $slug
                ) );
            } else {
            
                echo json_encode( array(
                    'status' => 0
                ) );
            }
            die();
        }
        
        /**
         * Processing ajax for save setting
         *
         * @return void
         */
        public function setting()
        {
            $error = false;
            if ( ! empty( $_POST['base_path'] )) {
                $path = sanitize_title( $_POST['base_path'] );
                update_option( '__ipvicre_base_path', $path );
            }
            if ( $error ) {
                $status = 0;
                $msg    = __( 'Failed to update settings.', 'wp_video_page_generator' );
            } else {
                $status = 1;
                $msg    = __( 'Successfully to update settings.', 'wp_video_page_generator' );
            }
            echo json_encode( array(
                'status'    => $status,
                'message'   => $msg
            ) );
            die();
        }
        
        /**
         * Processing ajax for save statistic data
         *
         * @return void
         */
        public function save_stat()
        {
            $error = true;
            if ( ! empty( $_POST['page_id'] ) && ! empty( $_POST['type'] )) 
            {
                $page_id = absint( $_POST['page_id'] );
                if ( $page = get_post( $page_id ))
                {
                    $type  = apply_filters( 'pre_term_name', $_POST['type'] );
                    $model = new IPVicre_Model();
                    $model->save_stat( $page, $type );
                    
                    $error = false;
                }
            }
            if ( $error ) {
                $status = 0;
                $msg    = __( 'Failed to save statistic data.', 'wp_video_page_generator' );
            } else {
                $status = 1;
                $msg    = __( 'Successfully to save statistic data.', 'wp_video_page_generator' );
            }
            echo json_encode( array(
                'status'    => $status,
                'message'   => $msg
            ) );
            die();
        }
        
        /**
         * Get chart
         *
         * @return void
         */
        public function get_chart()
        {
            $data = array_merge( $_POST, $_GET );
            if ( ! empty( $data['pageid'] ) && ! empty( $data['type'] )) 
            {
                $pageid    = absint( $data['pageid'] );
                $type      = apply_filters( 'pre_term_name', $data['type'] );
                $dateStart = false;
                $dateEnd   = false;
                if ( ! empty( $data['start'] ) && ! empty( $data['end'] )) {
                    $timeEnd   = strtotime( $data['end'] );
                    $timeStart = strtotime( $data['start'] );
                    $dateStart = gmdate("Y-m-d", $timeStart);
                    $dateEnd   = gmdate("Y-m-d", $timeEnd);
                }
                $model     = new IPVicre_Model();
                $chart     = array();
                $results   = $model->get_statistic_data( $pageid, $type, $dateStart, $dateEnd );
                
                if ( ! empty( $results )) {
                    foreach( $results as $data ) {
                        $timestamp = strtotime( $data->gdate );
                        $phpdate   = getdate($timestamp);
                        if ( $type == 'ctr' ) {
                            $value = 0;
                            if ( ! empty( $data->click ) && ! empty( $data->view )) {
                                $rate  = 100 * intval($data->click) / intval($data->view);
                                $rate  = round( $rate, 2 );
                                $value = $rate;
                            }
                        } else {
                            $value = (int)$data->value;
                        }
                        $chart[] = array(
                            'value'    => $value,
                            'year'     => $phpdate['year'],
                            'mon'      => $phpdate['mon'] - 1,
                            'day'      => $phpdate['mday'],
                        );
                    }
                }
                if ( $type == 'view' ) {
                    $label = __( 'Views', 'wp_video_page_generator' );
                } elseif ( $type == 'click' ) {
                    $label = __( 'Clicks', 'wp_video_page_generator' );
                } elseif ( $type == 'ctr' ) {
                    $label = __( 'CTR (in %)', 'wp_video_page_generator' );
                } else {
                    $label = __( 'Data', 'wp_video_page_generator' );
                }
                echo json_encode( array(
                    'status'            => 1,
                    'labelDate'         => __( 'Date', 'wp_video_page_generator' ),
                    'labelValue'        => $label,
                    'data'              => $chart
                ) );
            } else {
            
                echo json_encode( array(
                    'status' => 0
                ) );
            }
            die();
        }
        
        /**
         * Get more content
         *
         * @return void
         */
        public function get_more()
        {
            $page = false;
            if ( ! empty( $_POST['page_id'] )) {
                $page_id = absint( $_POST['page_id'] );
                $page    = get_post( $page_id );
            }
            if ( ! $page ) {
                echo '';
                die();
            }
            $paged = 1;
            if ( ! empty( $_POST['paged'] )) {
                $paged = absint( $_POST['paged'] );
            }
            $factory = new IPVicre_Factory();
            $factory->get_more_videos( $page, $paged );
            die();
        }
    }
}