<?php
if ( ! class_exists( 'IPVicre_List_Video' )) {

    /**
     * Class for create list video
     */
    class IPVicre_List_Video extends IPVicre_List
    {
        /**
         * Take page id
         *
         * @var id
         */
        protected $_page_id;
        
        /**
         * Class constructor
         *
         * @param  int $page_id
         * @return void
         */
        public function __construct( $page_id )
        {
            $this->_page_id = absint( $page_id );
            parent::__construct();
        }
        
        /**
         * Get data
         *
         * @return void
         */
        protected function _get_data()
        {
            $page     = $this->_page;
            $per_page = $this->_per_page;
            $args = array(
                'orderby'        => 'menu_order',
                'order'          => 'ASC', 
                'post_type'      => 'ipvicre-video-item',
                'post_status'    => array('publish','draft'),
                'posts_per_page' => $per_page,
                'paged'          => $page,
                'post_parent'    => $this->_page_id
            );
            $query = new WP_Query;
            $this->_result = $query->query( $args );
            $this->_query  = $query;
            $this->_total  = $query->found_posts;
            $this->_total_page = $this->_get_total_page();
            return $this->_result;
        }
        
        /**
         * Get item main
         *
         * @param  object $item
         * @param  int    $index
         * @return string
         */
        protected function _get_item_main( $item, $index )
        {
            $title  = $item->post_title;
            $date   = mysql2date( 'F d Y, h:i', $item->post_date );
            $link   = $this->_get_link_edit( $item );
            if ( $item->post_status == 'publish' ) {
                $label = '<span class="ipbe-label ipbe-label-success">' . __( 'Publish' ) . '</span>';
            } else {
                $label = '<span class="ipbe-label ipbe-label-danger">' . __( 'Draft' ) . '</span>';
            }
            $result = '<div class="col-sm-6">' .
                            '<div class="ipbe-item-main ipbe-clear">' .
                                '<div class="ipbe-item-move">' .
                                    '<i class="ibe ibe-arrows"></i>' .
                                '</div>' .
                                '<div class="ipbe-item-info">' .
                                    '<h3 class="ipbe-item-title">' . 
                                        '<a href="' . $link . '">' . $title . '</a>' . 
                                        '<span class="ipvicre-video-label">' .
                                            $label .
                                        '</span>' .
                                    '</h3>' .
                                    '<p class="ipbe-item-create">' . 
                                        '<i class="ibe ibe-calendar"></i>' .
                                        $date . 
                                    '</p>' .
                                '</div>' .
                            '</div>' .
                       '</div>';
            return $result;
        }
        
        /**
         * Get item action
         *
         * @param  object $item
         * @param  int    $index
         * @return string
         */
        protected function _get_item_action( $item, $index )
        {
            $result  = '<div class="col-sm-6">' .
                            '<div class="ipbe-item-action ipbe-clear">' .
                                '<div class="ipbe-item-nav text-right">' .
                                    '<a href="#" data-id="' . $item->ID . '" class="ipvicre-video-edit ipbe-btn ipbe-btn-success ipbe-btn-sm mr5">' .
                                        '<i class="ibe ibe-pencil"></i>' .
                                         __( 'Edit' ) . 
                                    '</a>' .
                                    '<a href="#" class="ipbe-btn ipbe-btn-danger ipbe-btn-sm ipvicre-video-delete " data-id="' . $item->ID . '">' .
                                        '<i class="ibe ibe-trash"></i>' .
                                        __( 'Delete' ) . 
                                    '</a>' .
                                '</div>' .
                            '</div>' .
                       '</div>';
            return $result;
        }
        
        /**
         * Get link edit
         *
         * @param  object $item
         * @return string
         */
        protected function _get_link_edit( $item )
        {
            $link = admin_url() . 'admin.php?page=ipvicre&action=edit&id=' . $item->ID;
            return $link;
        }
        
        /**
         * Get container
         *
         * @param  string $list
         * @return string
         */
        protected function _get_container( $list )
        {
            $result = '<div class="ipbe-manage container-fluid container">' .
                        '<div class="ipbe-manage-list ipbe-list-ordinal">' .
                            $list .
                        '</div>' .
                      '</div>';
            
            return $result;
        }
    }

}
?>