/*
 *===========================================================
 * Get more content
 *===========================================================*/
(function($)
{
    "use strict";
    
    /**
     * On Off button
     */
    $.fn.ipbe_more_content = function( options ) 
    {
        var defaults = {
            container:          '.more-content',
            contentContainer:   '.more-content-container',
            contentWrap:        '.more-content-wrap',
            ajaxUrl:            '',
            getAjaxData:        function( data ){return data;},
            successCallback:    function(){},
            errorCallback:      function(){},
            preCallback:        function(){},
            showMoreContent:    function(){},
            
            loaderContainer:    'body',
            loaderClass:        'more-content-loader',
            loaderImgUrl:       '',
            loaderText:         'Loading...',
            loaderBottom:       20,
            
            animateSpeed:       600,
            perPage:            20
        };
        var opt = $.extend( defaults, options );
                
        var winWidth   = $(window).width();
        var winHeight  = $(window).height();
        var pageHeight = $('body').height();
        
        var inProgress = false;
        var inStop     = false;
        
        $(window).scroll( function() 
        {
            if ( inProgress || inStop ) {
                return true;
            }
            var contTop    = $( opt.contentContainer ).position().top;
            var contHeight = $( opt.contentContainer ).height();
            var contBottom = contTop + contHeight;
            var scrollTop  = $(this).scrollTop();
            if ( scrollTop > ( contBottom - winHeight ) ) 
            {
                inProgress = true;
                var loader = getLoader();
                
                //Memunculkan loader
                showLoader( loader );
                
                //Callback sebelum memproses ajax
                opt.preCallback();
                
                var page = $( opt.container ).attr( 'data-page' );
                if ( ! page ) {
                    page = 1;
                }
                var pageNumber = new Number( page );
                var ajaxData = 'paged=' + ( pageNumber + 1 ) + '&perpage=' + opt.perPage;
                    ajaxData = opt.getAjaxData( ajaxData );
                
                //Ajax proses
                $.ajax({
                    url: opt.ajaxUrl,
                    type: "POST",
                    dataType: "html",
                    data: ajaxData,
                    success: function (result) 
                    {
                        if ( result.length > 10 ) {
                            opt.showMoreContent( result );
                        } else {
                            inStop = true;
                        }
                        opt.successCallback( result );
                        
                        //Menyembunyikan loader
                        hideLoader( loader );
                        //Set data
                        inProgress = false;
                        $( opt.container ).attr( 'data-page', pageNumber + 1 );
                    },
                    error: function (data) {
                        opt.errorCallback( data );
                    },
                });
                
            }
        });
        
        /*
         * Membentuk elemen loader
         */
        function getLoader()
        {
            if ( $( '.' + opt.loaderClass ).length < 1 )
            {
                var inner = $( '<div class="loader-inner"></div>' );
                //Add loader image
                if ( opt.loaderImgUrl != '' ) {
                    inner.append( '<img src="' + opt. loaderImgUrl + '" alt="">' );
                }
                //Add loader text
                if ( opt.loaderText != '' ) {
                    inner.append( '<span>' + opt.loaderText +'</span>' );
                }
                var loader = $( '<div class="' + opt.loaderClass + '"></div>' )
                                .append( inner )
                                .appendTo( $( opt.loaderContainer ) );
                
                //Memposisikan loader
                positioningLoader( loader );
            
            } else {
                var loader = $( opt.loaderClass );
            }
            return loader;
        }
        
        /*
         * Memposisikan loader
         */
        function positioningLoader( loader )
        {
            var width  = loader.width();
            var height = loader.height();
            var left  = ( winWidth - width )/2
            loader.css( 'position', 'fixed' )
                  .css( 'left', left )
                  .css( 'bottom', '-' + ( height + 100 ) + 'px' );
        }
        
        /*
         * Menampilkan loader
         */
        function showLoader( loader )
        {
            var height = loader.height();
            loader.animate({
                bottom: opt.loaderBottom + 'px'
            }, opt.animateSpeed );
        }
        
        /*
         * Menyembunyikan loader
         */
        function hideLoader( loader )
        {
            var height = loader.height();
            loader.animate({
                bottom: '-' + ( height + 100 ) + 'px'
            }, opt.animateSpeed );
        }
        
    };
    
})(jQuery);