<?php
/*
Plugin Name: WP Video Page Generator - Lite
Plugin URI: http://yourimhelper.com/plugin_uri
Version: 1.0
Author: <a href="http://yourimhelper.com/chris_jenkins" target="_blank">Chris Jenkins</a> &amp; <a href="http://yourimhelper.com/plugins_team" target="_blank">The PluginsForYou.com Team</a>
Author URI: http://yourimhelper.com/plugin_author_uri 
Description: Plugin that is used to make a video pages easily without having to know web slightest. | <a href="../wp-content/plugins/wp-video-page-generator-lite/wp-video-page-generator.pdf" title="WP Video Page Generator PDF User Manual" target="_blank">PDF User Manual</a> |
*/

/*  

*/

//Change this value for rebranding plugin
define( 'IPVICRE_TITLE', 'WP Video Page Generator - Lite' );
define( 'IPVICRE_FILE', __FILE__ );
define( 'IPVICRE_PATH', plugin_dir_path( __FILE__ ) );
define( 'IPVICRE_BASE_URL', plugin_dir_url( __FILE__ ) );

require_once( IPVICRE_PATH . "app/setting.php" );
require_once( IPVICRE_PATH . "app/db.php" );
require_once( IPVICRE_PATH . "app/font.php" );
require_once( IPVICRE_PATH . "app/ajax.php" );
require_once( IPVICRE_PATH . "app/admin.php" );
require_once( IPVICRE_PATH . "app/list.php" );
require_once( IPVICRE_PATH . "app/list-video.php" );
require_once( IPVICRE_PATH . "app/model.php" );
require_once( IPVICRE_PATH . "app/factory.php" );

/**
 * Main class
 */
if ( ! class_exists( 'IPVicre' )) {

    class IPVicre
    {
        /**
         * Setup Plugin
         */
        public static function setup()
        {
            $hook = sanitize_title( IPVICRE_TITLE );
            
            //Register admin menu
            add_action( 'admin_menu', array( __CLASS__, 'add_admin_menu' ) );
            
            //Plugin init
            add_action( 'admin_init', array( __CLASS__, 'admin_init' ) );
            
            //Install Plugin
            register_activation_hook( __FILE__, array( __CLASS__, 'install' ) );
            
            //Hook for plugin loaded
            add_action( 'plugins_loaded', array( __CLASS__, 'update_db' ) );
            
            //Rewrite Handler
            add_action( 'init', array( __CLASS__, 'rewrite_flush' ) );
            add_action( 'pre_get_posts', array( __CLASS__, 'init' ) );
            
            //Render page
            add_action( 'template_redirect', array( __CLASS__, 'factory' ) );
             
            //Add admin style & script
            add_action( 'admin_print_styles', array( __CLASS__, 'admin_style_global' ), 1000 );
            add_action( 'admin_print_styles-toplevel_page_ipvicre', array( __CLASS__, 'admin_style' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_ipvicre-add', array( __CLASS__, 'admin_style' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_ipvicre-statistic', array( __CLASS__, 'admin_style' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_ipvicre-setting', array( __CLASS__, 'admin_style' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_ipvicre-support', array( __CLASS__, 'admin_style' ), 1000 );
            
            add_action( 'admin_print_scripts-toplevel_page_ipvicre', array( __CLASS__, 'admin_script' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ipvicre-add', array( __CLASS__, 'admin_script' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ipvicre-statistic', array( __CLASS__, 'admin_script' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ipvicre-setting', array( __CLASS__, 'admin_script' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_ipvicre-support', array( __CLASS__, 'admin_script' ), 1000 );
            
            /* 
            //Front style & script
            add_action('wp_head', array( __CLASS__, 'public_style' ) );
            
            if ( ! is_admin() ) {
                add_action('wp_enqueue_scripts', array( __CLASS__, 'public_script' ), 10 );
            } 
            */
        }
        
        /**
         * Add administrator menu
         *
         * @return void
         */
        public static function add_admin_menu()
        {
            add_menu_page( 
                IPVICRE_TITLE, 
                IPVICRE_TITLE, 
                'ipvicre_manage', 
                'ipvicre',
                array( __CLASS__, 'admin' ), 
                plugin_dir_url( __FILE__ ) . 'img/menu_icon.png'
            );
            add_submenu_page( 
                'ipvicre',
                __( 'Dashboard', 'wp_video_page_generator' ), 
                __( 'Dashboard', 'wp_video_page_generator' ), 
                'ipvicre_manage', 
                'ipvicre',
                array( __CLASS__, 'admin' )
            );
            add_submenu_page( 
                'ipvicre',
                __( 'Add Video Page', 'wp_video_page_generator' ), 
                __( 'Add Video Page', 'wp_video_page_generator' ), 
                'ipvicre_manage', 
                'ipvicre-add',
                array( __CLASS__, 'admin_add' )
            );
            add_submenu_page( 
                'ipvicre',
                __( 'Settings', 'wp_video_page_generator' ), 
                __( 'Settings', 'wp_video_page_generator' ), 
                'ipvicre_manage', 
                'ipvicre-setting',
                array( __CLASS__, 'admin_setting' )
            );
        }
        
        /**
         * Admin Init
         *
         * @return void
         */
        public static function admin_init()
        {
            global $wp_roles;
            
            /** 
             * Register Roles
             */
            // Add capability for administrator
            $role = get_role( 'administrator' );
            $role->add_cap( 'ipvicre_manage' );
            
            $wp_roles->reinit();
            
            /**
             * Ajax handler
             **/
            $ajax = new IPVicre_Ajax();
            $ajax->exec();
        }
        
        /**
         * Content for administrator page
         *
         * @return void
         */
        public static function admin()
        {
            $display = new IPVicre_Admin();
            if ( ! empty( $_GET['action'] ) && $_GET['action'] == 'edit' ) {
                $display->edit();
            } else {
                $display->index();
            }
        }
        
        /**
         * Content for administrator add video page
         *
         * @return void
         */
        public static function admin_add()
        {
            $display = new IPVicre_Admin();
            $display->add();
        }
        
        /**
         * Content for administrator setting page
         *
         * @return void
         */
        public static function admin_setting()
        {
            $display = new IPVicre_Admin();
            $display->setting();
        }
        
        /**
         * Install plugin
         *
         * @return void
         */
        public static function install()
        {
            //Rewrite
            self::rewriteInit();
            flush_rewrite_rules();
            
            //Db
            $db = new IPVicre_Db();
            $db->install();
        }
        
        /**
         * Update database
         *
         * @return void
         */
        public static function update_db()
        {
            $db = new IPVicre_Db();
            $db->update();
        }
        
        /**
         * Init request
         *
         * @return void
         */
        public static function init( $query )
        {
            $q = $query->query;
            if ( isset( $q['ipvicre'] ) && isset( $q['video_page_name'] )) {
                $query->query_vars['post_type'] = 'ipvicre-item';
                $query->query_vars['name']      = $q['video_page_name'];
                $query->query_vars['pagename']  = $q['video_page_name'];
                $query->query['pagename']       = $q['video_page_name'];
            
            } elseif( isset( $q['video_page_id'] )) {
                $query->query_vars['post_type'] = 'ipvicre-item';
                $query->query_vars['p']         = absint( $q['video_page_id'] );
            }
        }
        
        /**
         * Init rewrite rule
         *
         * @return void
         */
        public static function rewriteInit()
        {
            $base = get_option( '__ipvicre_base_path', 'video-page' );
            add_rewrite_rule(
                $base . '/([^/]+)/?$',
                'index.php?ipvicre=1&video_page_name=$matches[1]',
                'top'
            );
            add_rewrite_rule(
                $base . '/([^/]+)/feed/(feed|rdf|rss|rss2|atom)/?$',
                'index.php?ipvicre=1&video_page_name=$matches[1]&feed=$matches[2]',
                'top'
            );
            add_rewrite_rule(
                $base . '/([^/]+)/(feed|rdf|rss|rss2|atom)/?$',
                'index.php?ipvicre=1&video_page_name=$matches[1]&feed=$matches[2]',
                'top'
            );
            add_rewrite_rule(
                $base . '/([^/]+)/page/?([0-9]{1,})/?$',
                'index.php?ipvicre=1&video_page_name=$matches[1]&paged=$matches[2]',
                'top'
            );
            add_rewrite_tag( '%video_page_name%', '([a-zA-Z0-9\_])');
            add_rewrite_tag( '%video_page_id%', '([0-9])');
            add_rewrite_tag( '%ipvicre%', '([1])');
        }
        
        /**
         * Flush rewrite rule
         *
         * @return void
         */
        public static function rewrite_flush()
        {
            $base = get_option( '__ipvicre_base_path', 'video-page' );
            $old  = get_option( '__ipvicre_base_path_old', 'video-page' );
            
            self::rewriteInit();
            
            if ( $base != $old ) {
                flush_rewrite_rules();
                update_option( '__ipvicre_base_path_old', $base );
            }
        }
        
        /**
         * Video page factory
         *
         * @return void
         */
        public static function factory()
        {
            //Factory
            $factory = new IPVicre_Factory();
            $factory->render();
        }

        /**
         * Print admin style
         *
         * @return void
         */
        public static function admin_style()
        {
            wp_deregister_style('insta-backend-style');
            wp_register_style('insta-backend-style', plugin_dir_url( __FILE__ ) . 'css/ipbe-admin.css', false, null);
            wp_enqueue_style('insta-backend-style');
            
            wp_deregister_style('ipvicre-admin-style');
            wp_register_style('ipvicre-admin-style', plugin_dir_url( __FILE__ ) . 'css/admin.css', false, null);
            wp_enqueue_style('ipvicre-admin-style');
        }

        /**
         * Print admin style
         *
         * @return void
         */
        public static function admin_style_global()
        {
            wp_deregister_style('ipvicre-admin-style-global');
            wp_register_style('ipvicre-admin-style-global', plugin_dir_url( __FILE__ ) . 'css/admin-global.css', false, null);
            wp_enqueue_style('ipvicre-admin-style-global');
        }

        /**
         * Print Admin Script
         *
         * @return void
         */
        public static function admin_script($hook)
        {
        ?>
        <script type="text/javascript">
            var ipvicre_img_url = '<?php echo IPVICRE_BASE_URL . 'img/'; ?>',
                ipbe_base       = '<?php echo IPVICRE_BASE_URL; ?>',
                ip_ui_message   = 
                {
                    delete_confirm_title: '<?php _e( 'Delete Confirmation', 'wp_video_page_generator' ); ?>',
                    delete_confirm_info: '<?php _e( 'Are you sure doing this action?', 'wp_video_page_generator' ); ?>'
                };
        </script>
        <?php
            wp_deregister_script('insta-backend-script');
            wp_enqueue_script(
                'insta-backend-script',
                plugin_dir_url( __FILE__ ) . 'js/ipbe-admin.min.js',
                array( 'jquery' ),
                1,
                true
            );
            wp_deregister_script('ipvicre-admin-script');
            wp_enqueue_script(
                'ipvicre-admin-script',
                plugin_dir_url( __FILE__ ) . 'js/admin.min.js',
                array( 'jquery' ),
                1,
                true
            );
        }

        /**
         * Print public style
         *
         * @return void
         */
        public static function public_style()
        {
            global $ipvicre;
            
            if ( ! $ipvicre ) {
                $ipvicre = new IPVicre_Factory();
            }
            $setting = $ipvicre->setting();
            $name    = $setting->getSetting( 'font_family', 'roboto' );
            $fonts   = IPVicre_Font::getLinks();
            if ( array_key_exists( $name, $fonts )) 
            {
                $family  = $fonts[$name];
                $fontUrl = 'http://fonts.googleapis.com/css?family=' . $family;
                echo '<link id="ipvicre-font" href="' . $fontUrl . '" rel="stylesheet" type="text/css">';
            }
        ?>
            <script type="text/javascript">
                var ipvicre_ajaxurl = "<?php echo admin_url( 'admin-ajax.php' ); ?>";
                var ipvicre_scroll  = "<?php echo $setting->getSetting( 'scroll_show', 0 ); ?>";
            </script>
            <link media="all" type="text/css" href="<?php echo plugin_dir_url( __FILE__ ) ?>css/public.min.css" rel="stylesheet">
        <?php
        }

        /**
         * Print public script
         *
         * @return void
         */
        public static function public_script()
        {
            wp_enqueue_script('jquery');
            
            wp_deregister_script('jquery-ui');
            wp_register_script('jquery-ui', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jqueryui/1.10.4/jquery-ui.min.js", false, null);
            wp_enqueue_script('jquery-ui');
            
            wp_deregister_script('ipvicre-public-script');
            wp_enqueue_script(
                'ipvicre-public-script',
                plugin_dir_url( __FILE__ ) . 'js/public.min.js',
                array( 'jquery' ),
                1,
                true
            );
        }
    }

}
//Run plugin
IPVicre::setup();
?>